# CBpanel "QuickTerminal" plugin

name = "QuickTerminal"
description = "An always-ready terminal on CBpanel"

import CBpanel
import gtk
import vte
import os

class TerminalWindow(CBpanel.PopupWindow):
    def __init__(self, panel):
        CBpanel.PopupWindow.__init__(self, panel, 3, gtk.WINDOW_TOPLEVEL)
        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)
        terminal = vte.Terminal()
        self.connect("focus-in-event", lambda w,e: terminal.grab_focus())
        terminal.set_emulation("xterm")
        terminal.set_font_from_string("monospace 10")
        terminal.set_allow_bold(True)
        terminal.set_scrollback_lines(1000)
        terminal.show()
        box = gtk.HBox(False, 2)
        self.add(box)
        box.add(terminal)
        box.show()
        scrollbar = gtk.VScrollbar()
        scrollbar.show()
        scrollbar.set_adjustment(terminal.get_adjustment())
        box.add(scrollbar)

        ## start in home directory
        os.chdir(os.getenv('HOME'))
        terminal.fork_command()
        os.chdir(panel.root_path)
        #~ terminal.feed_child('cd && clear\n')
        terminal.connect("child-exited", self.__cb_exited)

    def __cb_exited(self, terminal):
        terminal.fork_command()
        self.toggle()

class Plugin(CBpanel.Plugin):
    def __init__(self, panel, settings):
        CBpanel.Plugin.__init__(self, panel, settings)

        self._twindow = TerminalWindow(panel)
        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self._twindow.toggle)
        btn.set_relief(gtk.RELIEF_NONE)
        btn.set_border_width(0)
        btn.set_focus_on_click(False)
        btn.set_property('can-focus', False)
        self.add(btn)

        aicon = "gnome-terminal"

        if settings.has_key('icon') and settings['icon']!=None:
            aicon = settings['icon']

        if len(aicon)>0:
            img = self.panel.get_image_from_icon_name(aicon)
            btn.add(img)

        self.show_all()
